@@ -144,9 +144,7 @@ bool gcpTextTool::OnClicked()
 {
 	void *func;
 	if (m_Active && ((m_pObject == NULL) || (m_pObject->GetType() != TextType) || (m_Active != m_pData->Items[m_pObject]->item_list->data)))
-	{
 		Unselect();
-	}
 	if (!m_pObject)
 	{
 		gcpText *text = new gcpText(m_x0 / m_pData->ZoomFactor, m_y0 / m_pData->ZoomFactor);
@@ -163,6 +161,7 @@ bool gcpTextTool::OnClicked()
 		g_object_set(G_OBJECT(m_Active), "editable", true, "cursor_visible", true, NULL);
 		m_CurNode = ((gcpText*)m_pObject)->SaveSelected();
 		m_InitNode = ((gcpText*)m_pObject)->SaveSelected();
+		ActivateMenu (FileMenu, SaveAsImageMenu, false);
 	}
 	return true;
 }
@@ -356,6 +355,7 @@ bool gcpTextTool::Unselect()
 		m_pView->GetDoc()->Remove(pObj);
 		m_pView->GetDoc()->AbortOperation();
 	}
+	ActivateMenu (FileMenu, SaveAsImageMenu, m_pView->GetDoc()->HasChildren ());
 	return true;
 }
 
