@@ -4,9 +4,9 @@
  * GChemPaint
  * view.cc
  *
- * Copyright (C) 2001-2003
+ * Copyright (C) 2001-2004
  *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -286,7 +286,10 @@ bool gcpView::OnEvent(GnomeCanvasItem *item, GdkEvent *event, GtkWidget* widget)
 				return true;
 			}
 			case 3:
+#ifdef GCU_OLD_VER
 				if (Obj) Obj->ShowContextualMenu(event->button.button, event->button.time);
+#endif
+				break;
 		}
 		break;
 	case GDK_MOTION_NOTIFY:
@@ -772,6 +775,7 @@ void gcpView::OnSelectAll()
 void gcpView::ExportImage (const char* filename, const char* type)
 {
 	ArtDRect rect;
+	m_pData->ShowSelection (false);
 	m_pData->GetObjectBounds (m_pDoc, &rect);
 	int w = (int) (ceil (rect.x1) - floor (rect.x0)), h = (int) (ceil (rect.y1) - floor (rect.y0));
 	if (!strcmp (type, "eps")) {
@@ -797,7 +801,7 @@ void gcpView::ExportImage (const char* filename, const char* type)
 		char *command_line = g_strconcat ("ps2eps ", tmpname, NULL);
 		g_spawn_command_line_sync (command_line, NULL, NULL, NULL, NULL);
 		g_free (command_line);
-		command_line = g_strconcat ("mv -f ", tmpname, ".eps ", filename);
+		command_line = g_strconcat ("mv -f ", tmpname, ".eps ", filename, NULL);
 		g_spawn_command_line_async (command_line, NULL);
 		remove (tmpname);
 		g_free (tmpname);
@@ -814,8 +818,10 @@ void gcpView::ExportImage (const char* filename, const char* type)
 		buf.rect.y1 = (int) ceil (rect.y1);
 		buf.buf_rowstride = gdk_pixbuf_get_rowstride (pixbuf);
 		buf.bg_color = 0xffffff;
+		buf.is_buf = 1;
 		(* GNOME_CANVAS_ITEM_GET_CLASS (m_pData->Group)->render) (GNOME_CANVAS_ITEM (m_pData->Group), &buf);
 		gdk_pixbuf_save (pixbuf, filename, type, NULL, NULL);
 		g_object_unref (pixbuf);
 	}
+	m_pData->ShowSelection (true);
 }
